@@ -230,7 +230,12 @@ bool ScriptInterp::setConst(const char *id, const char *value)
 {
 	MutexLock lock(*this);
 	Symbol *sym;
-	unsigned short len = (unsigned short)strlen(value);
+	unsigned short len;
+
+	if(!value)
+		return false;
+
+	len = (unsigned short)strlen(value);
 
 	sym = mapSymbol(id, len);
 
@@ -720,6 +725,7 @@ void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
 	ScriptImage::InitialList *ilist;
 	ScriptBinder *mod = ScriptBinder::first;
 	Name *init;
+	Line *line;
 	stack = 0;
 	cmd = cmdref;
 	exiting = initialized = false;
@@ -764,7 +770,19 @@ void ScriptInterp::attach(ScriptCommand *cmdref, ScriptImage *img, Name *scr)
 	enterMutex();
 	initRuntime(scr);
 	if(fastStart)
+	{
 		image->fastBranch(this);
+		goto finish;
+	}
+	
+	line = getLine();
+	if(!line)
+		goto finish;
+
+	if(!stricmp(line->cmd, "options"))
+		execute(line->scr.method);
+
+finish:
 	leaveMutex();
 }
 
