@@ -695,12 +695,7 @@ bool ScriptMethods::scrExit(void)
 
 bool ScriptMethods::scrSignal(void)
 {
-	const char *cp = getMember();
-
-	if(cp)
-		branching(cp);
-
-	cp = getOption(NULL);
+	const char *cp = getOption(NULL);
 
 	if(!cp)
 	{
@@ -722,13 +717,8 @@ bool ScriptMethods::scrSignal(void)
 
 bool ScriptMethods::scrThrow(void)
 {
-	const char *cp = getMember();
 	Line *line = getLine();
-
-	if(cp)
-		branching(cp);
-
-	cp = getOption(NULL);
+	const char *cp = getOption(NULL);
 
 	if(!cp)
 	{
@@ -742,11 +732,6 @@ bool ScriptMethods::scrThrow(void)
 
 bool ScriptMethods::scrGoto(void)
 {
-	const char *cp = getMember();
-
-	if(cp)
-		branching(cp);
-
 	frame[stack].tranflag = false;
 	if(image->isRipple())
 	{
@@ -758,12 +743,8 @@ bool ScriptMethods::scrGoto(void)
 
 bool ScriptMethods::scrRestart(void)
 {
-	const char *cp = getMember();
-
-	if(cp)
-		branching(cp);
-
 	clearStack();
+	branching();
 
 	frame[stack].caseflag = frame[stack].tranflag = false;
 	frame[stack].line = frame[stack].first = frame[stack].script->first;
@@ -1413,15 +1394,11 @@ bool ScriptMethods::scrReturn(void)
 	unsigned len = symsize;
 	unsigned argc = 0;
 	Name *scr;
-	const char *member = getMember();
 	char *n;
 
 	if(label && *label != '@' && *label != '{')
 		label = getContent(label);
 
-	if(member)
-		branching(member);
-
 	tempidx = 0;
 	while(argc < line->argc)
 	{
@@ -1554,16 +1531,12 @@ bool ScriptMethods::scrCall(void)
 {
         Line *line = getLine();
 	unsigned prior = stack;
-	const char *member = getMember();
 	const char *cmd = line->cmd;
 	const char *cp, *vp;
 	bool trans = false;
 	unsigned idx = 0;
 	Symbol *sym;
 
-	if(member)
-		branching(member);
-
 	if(!push())
 	{
 		error("stack-overflow");
