@@ -80,13 +80,16 @@ const char *Script::access_pass = NULL;
 const char *Script::access_host = "localhost";
 
 #ifdef	WIN32
+const char *Script::apps_extensions = ".app.apps";
 const char *Script::exec_extensions = ".bat";
 #else
+const char *Script::apps_extensions = ".app.exec.apps";
 const char *Script::exec_extensions = ".sh";
 #endif
 const char *Script::exec_token = "script:";
 const char *Script::exec_prefix = "exec";
 const char *Script::exit_token = "exit";
+const char *Script::apps_prefix = "libexec";
 
 Script::Test *Script::test = NULL;
 Script::Fun *Script::ifun = NULL;
