@@ -57,6 +57,7 @@
 #define	SCRIPT_STACK_SIZE 32
 #define	SCRIPT_ROUTE_SLOTS 16
 #define	SCRIPT_EXEC_WRAPPER
+#define	SCRIPT_APPS_WRAPPER
 
 #ifndef CCXX_PACKING
 #if defined(__GNUC__)
@@ -269,6 +270,8 @@ public:
 	static const char *exec_token;
 	static const char *exec_prefix;
 	static const char *exit_token;
+	static const char *apps_extensions;
+	static const char *apps_prefix;
 
         static void addFunction(const char *name, unsigned count, Function i);
         static void addConditional(const char *name, Cond test);
